@@ -9,7 +9,8 @@ PAD_PCT = 0.2
 
 def plot_forecast(fcst_df: pd.DataFrame, orig_data: np.ndarray, orig_dates: pd.DatetimeIndex,
                   ax: Optional[plt.Axes] = None, figsize: Tuple[int, int] = (12, 5),
-                  xlabel: Optional[str] = None, ylabel: Optional[str] = None) -> plt.Figure:
+                  xlabel: Optional[str] = None, ylabel: Optional[str] = None,
+                  title: Optional[str] = None) -> plt.Figure:
     if ax is None:
         fig = plt.figure(facecolor='w', figsize=figsize)
         ax = fig.add_subplot(111)
@@ -28,10 +29,13 @@ def plot_forecast(fcst_df: pd.DataFrame, orig_data: np.ndarray, orig_dates: pd.D
     y_lim_upper = max_point * (1 + PAD_PCT)
     y_lim_lower = min_point * (1 - PAD_PCT)
     ax.set_ylim([y_lim_lower, y_lim_upper])
+    ax.grid(True, which='major', c='gray', ls='-', lw=1, alpha=0.2)
     if xlabel is not None:
         ax.set_xlabel(xlabel)
     if ylabel is not None:
         ax.set_ylabel(ylabel)
+    if title is not None:
+        ax.set_title(title)
     plt.close()
 
     return fig
